@@ -2,11 +2,15 @@
 
 import yaml
 import time
-
+import os
 
 path = 'stack.yaml'
 
 
+def exist() -> bool:
+    return os.path.exists(path)
+
+
 def load() -> dict:
     with open(path, 'r+') as f:
         return yaml.load(''.join(f.readlines()))
